@@ -4,7 +4,6 @@
 #' @param input_gr A GenomicRanges object
 #' @param minusOneToEnd Minus one position to end of each Genomic Range?
 #' @keywords Genomic Ranges position
-#' @importFrom GenomicRanges seqnames GRanges
 #' @examples 
 #' load(system.file("extdata","nbl_result_matrix_sign_small.rda",package = "CNVScope")) 
 #' col_gr<-underscored_pos_to_GRanges(colnames(nbl_result_matrix_sign_small))
@@ -12,7 +11,8 @@
 #' @export
 GRanges_to_underscored_pos<-function(input_gr,minusOneToEnd=T)
 {
+  #importFrom GenomicRanges seqnames GRanges
   if(minusOneToEnd){adjustment<-1} else {adjustment=0}
-  output_char<-paste0(seqnames(input_gr),"_",input_gr@ranges@start,"_",input_gr@ranges@start+input_gr@ranges@width-adjustment)
+  output_char<-paste0(GenomicRanges::seqnames(input_gr),"_",input_gr@ranges@start,"_",input_gr@ranges@start+input_gr@ranges@width-adjustment)
   return(output_char)
 }
\ No newline at end of file
